pub struct IgnoreEntry {
pub path: String,
pub rules: Vec<String>,
}Expand description
Suppress specific rules for paths whose string representation ends with
path. An empty rules vec suppresses all rules for matching paths.
Fields
path: Stringrules: Vec<String>Trait Implementations
Sourceimpl Clone for IgnoreEntry
impl Clone for IgnoreEntry
Sourcefn clone(&self) -> IgnoreEntry
fn clone(&self) -> IgnoreEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for IgnoreEntry
impl RefUnwindSafe for IgnoreEntry
impl Send for IgnoreEntry
impl Sync for IgnoreEntry
impl Unpin for IgnoreEntry
impl UnsafeUnpin for IgnoreEntry
impl UnwindSafe for IgnoreEntry